@@ -85,6 +85,12 @@ public class DefaultClient implements Client {
             }
         }
 
+        // Diag
+        if (Environment.DIAG.removeCommandLineOption(args) != null) {
+            org.jline.terminal.impl.Diag.diag(System.out);
+            return;
+        }
+
         // Serial
         if (Environment.SERIAL.removeCommandLineOption(args) != null) {
             System.setProperty(Environment.SERIAL.getProperty(), Boolean.toString(true));
@@ -165,7 +171,7 @@ public class DefaultClient implements Client {
             } catch (DaemonException.InterruptedException e) {
                 final AttributedStyle s = new AttributedStyle().bold().foreground(AttributedStyle.RED);
                 String str = new AttributedString(System.lineSeparator() + "Canceled by user", s).toAnsi();
-                output.accept(Message.display(str));
+                output.accept(Message.err(str));
                 exitCode = 130;
             }
         }
